/*
 * Statistics.h
 *
 *  Created on: Oct 17, 2010
 *      Author: dick
 */

#ifndef _STATISTICS_H_
#define _STATISTICS_H_

#include <string>
#include <set>

#include <boost/thread.hpp>

namespace berzerk {
namespace statistics {

using namespace std;

class StatLine {
  public:
	StatLine();
	StatLine(const string& ip, const string& rule, const string& deathLine);
	string	toXML();
	string	getTime();

	string	ip;
	string	rule;
	string	deathLine;
	time_t	sldate;

};


class Statistics {
	friend class StatServer;
  public:
	Statistics();

	void		lock();
	void		unlock();
	void		incLinesRead();
	int			getLinesRead();
	void		incKilled(const string& ip, const string& rule, const string& deathLine);
	int			getIPsKilled();

	const boost::mutex& getMutex() const;

  private:
	boost::mutex myMutex;

	int			linesRead;
	int			ipsKilled;
	string		lastLogLine;
	set<string>	ipsKilledSet;
  public:
	list<StatLine*>	statLines;
};

inline StatLine::StatLine() { sldate = time(NULL); }
inline StatLine::StatLine(const string& _ip, const string& _rule, const string& _deathLine) {
	ip = _ip; rule = _rule; deathLine = _deathLine; sldate = time(NULL);
}

inline void Statistics::incLinesRead() { linesRead++; }
inline int Statistics::getLinesRead() { return(linesRead); }
inline int Statistics::getIPsKilled() { return(ipsKilled); }
inline void Statistics::lock() { myMutex.lock(); }
inline void Statistics::unlock() { myMutex.unlock(); }

inline const boost::mutex& Statistics::getMutex() const { return(myMutex); }
}	// namespace statistics
}	// berzerk

#endif /* _STATISTICS_H_ */
