/*******************************************************************************
*  WebHandler - Determine what the client is asking for and return it.
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright(c) 2011 - BuckoSoft, Inc.
*
*  http://git.buckosoft.com/gitweb/?p=Berzerk.git;a=history;f=Berzerk/StatServer.h
*
\*******************************************************************************/

#ifndef	_WEBHANDLER_H_
#define	_WEBHANDLER_H_

#include "server/reply.hpp"
#include "server/RequestProcessor.hpp"
#include "Statistics.h"

using namespace http::server;

#if 0
XERCES_CPP_NAMESPACE_BEGIN
	class DOMDocument;
XERCES_CPP_NAMESPACE_END
XERCES_CPP_NAMESPACE_USE
#endif


namespace berzerk {

using namespace statistics;
extern	PCSTR	s_xml_preamble;

extern	string	toXml(PCSTR element, const string& value, int indent = 0);
extern	string	xmlToken(const string& s);
extern	string	xmlTokenE(const string& s);

class WebHandler : public http::server::RequestProcessor {
  public:
	virtual ~WebHandler();
	void setStatistics(Statistics* statistics);
	reply::status_type		handleRequest(const  ::std::string& uri, const http::server::request& req, http::server::reply& rep);

	static void	setDEBUG(int value);

  private:
	Statistics*	statistics = NULL;

	reply::status_type	doPublicIndex(reply& rep);
	reply::status_type	doStatistics(string args, reply& rep);
	reply::status_type	doTestFilter(string args, reply& rep);
	reply::status_type	doReject(string args, reply& rep);
	reply::status_type	doFile(const string& filename, reply& rep);
	reply::status_type	doGetLogFiles(reply& rep);
	reply::status_type	doStatus(reply& rep);

	string		toXML(StatLine* sl);

#if 0
	string				domToString(DOMDocument* doc);
#endif

	static	int	DEBUG;
};

inline void WebHandler::setStatistics(Statistics* s) { statistics = s; }
inline WebHandler::~WebHandler() { statistics = NULL; }
inline void WebHandler::setDEBUG(int level) { DEBUG = level; }

}	// namespace berzerk
#endif	// _WEBHANDLER_H_
